@@ -1,5 +1,3 @@
-package org.apache.maven.shared.utils.io;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.utils.io;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,23 +16,23 @@ package org.apache.maven.shared.utils.io;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.utils.io;
 
 import java.io.File;
 
 /**
  * DirectoryWalkListener.
- * 
+ *
  * @deprecated use {@code java.nio.file.FileVisitor} and related classes
  */
 @Deprecated
-public interface DirectoryWalkListener
-{
+public interface DirectoryWalkListener {
     /**
      * The directory walking has begun.
      *
      * @param basedir the basedir that walk started in
      */
-    void directoryWalkStarting( File basedir );
+    void directoryWalkStarting(File basedir);
 
     /**
      * The included entry that was encountered.
@@ -42,7 +40,7 @@ public interface DirectoryWalkListener
      * @param percentage rough percentage of the walk completed. (inaccurate)
      * @param file       the file that was included
      */
-    void directoryWalkStep( int percentage, File file );
+    void directoryWalkStep(int percentage, File file);
 
     /**
      * The directory walking has finished.
@@ -52,5 +50,5 @@ public interface DirectoryWalkListener
     /**
      * @param message the message for the debugging output
      */
-    void debug( String message );
+    void debug(String message);
 }
