@@ -1,5 +1,3 @@
-package org.apache.maven.shared.utils.exceptionutils;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.utils.exceptionutils;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,29 +16,25 @@ package org.apache.maven.shared.utils.exceptionutils;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.utils.exceptionutils;
 
 /**
  * This test exception has a 'detail' field.
  *
  * @author <a href="mailto:struberg@yahoo.de">Mark Struberg</a>
  */
-public class TestExceptionWithDetail
-    extends Exception
-{
+public class TestExceptionWithDetail extends Exception {
     private Throwable detail;
 
-    public TestExceptionWithDetail()
-    {
+    public TestExceptionWithDetail() {
         super();
     }
 
-    public Throwable getDetail()
-    {
+    public Throwable getDetail() {
         return detail;
     }
 
-    public void setDetail( Throwable detail )
-    {
+    public void setDetail(Throwable detail) {
         this.detail = detail;
     }
 }
