@@ -1,5 +1,3 @@
-package org.apache.maven.shared.utils.io;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.utils.io;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.utils.io;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.utils.io;
 
 import org.junit.Test;
 
@@ -26,15 +25,13 @@ import static org.junit.Assert.*;
 /**
  * @author Kristian Rosenvold
  */
-@SuppressWarnings( "deprecation" )
-public class MatchPatternsTest
-{
+@SuppressWarnings("deprecation")
+public class MatchPatternsTest {
     @Test
-    public void matches()
-    {
-        MatchPatterns from = MatchPatterns.from( "ABC**", "CDE**" );
-        assertTrue( from.matches( "ABCDE", true ) );
-        assertTrue( from.matches( "CDEF", true ) );
-        assertFalse( from.matches( "XYZ", true ) );
+    public void matches() {
+        MatchPatterns from = MatchPatterns.from("ABC**", "CDE**");
+        assertTrue(from.matches("ABCDE", true));
+        assertTrue(from.matches("CDEF", true));
+        assertFalse(from.matches("XYZ", true));
     }
 }
